#[repr(u8)]pub enum Cmdsrc {
Show 16 variants
Cmdsrc0 = 0,
Cmdsrc1 = 1,
Cmdsrc2 = 2,
Cmdsrc3 = 3,
Cmdsrc4 = 4,
Cmdsrc5 = 5,
Cmdsrc6 = 6,
Cmdsrc7 = 7,
Cmdsrc8 = 8,
Cmdsrc9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
Cmdsrc15 = 15,
}Variants
Cmdsrc0 = 0
Not a valid value CMDSRC value for a dataword in RESFIFO. 0x0 is only found in initial FIFO state prior to an ADC conversion result dataword being stored to a RESFIFO buffer.
Cmdsrc1 = 1
CMD1 buffer used as control settings for this conversion.
Cmdsrc2 = 2
Corresponding command buffer used as control settings for this conversion.
Cmdsrc3 = 3
Corresponding command buffer used as control settings for this conversion.
Cmdsrc4 = 4
Corresponding command buffer used as control settings for this conversion.
Cmdsrc5 = 5
Corresponding command buffer used as control settings for this conversion.
Cmdsrc6 = 6
Corresponding command buffer used as control settings for this conversion.
Cmdsrc7 = 7
Corresponding command buffer used as control settings for this conversion.
Cmdsrc8 = 8
Corresponding command buffer used as control settings for this conversion.
Cmdsrc9 = 9
Corresponding command buffer used as control settings for this conversion.
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
Cmdsrc15 = 15
CMD15 buffer used as control settings for this conversion.