#[repr(u8)]pub enum Fof1 {
FOF1_0 = 0,
FOF1_1 = 1,
}Variants
FOF1_0 = 0
No result FIFO1 overflow has occurred since the last time the flag was cleared.
FOF1_1 = 1
At least one result FIFO1 overflow has occurred since the last time the flag was cleared.
Implementations