#[repr(u8)]pub enum Fofie1 {
FOFIE1_0 = 0,
FOFIE1_1 = 1,
}Variants
FOFIE1_0 = 0
No result FIFO1 overflow has occurred since the last time the flag was cleared.
FOFIE1_1 = 1
At least one result FIFO1 overflow has occurred since the last time the flag was cleared.
Implementations