#[repr(u8)]pub enum Tprictrl {
TPRICTRL_0 = 0,
TPRICTRL_1 = 1,
TPRICTRL_2 = 2,
_RESERVED_3 = 3,
}Variants
TPRICTRL_0 = 0
If a higher priority trigger is detected during command processing, the current conversion is aborted and the new command specified by the trigger is started.
TPRICTRL_1 = 1
If a higher priority trigger is received during command processing, the current command is stopped after after completing the current conversion. If averaging is enabled, the averaging loop will be completed. However, CMDHa[LOOP] will be ignored and the higher priority trigger will be serviced.
TPRICTRL_2 = 2
If a higher priority trigger is received during command processing, the current command will be completed (averaging, looping, compare) before servicing the higher priority trigger.
_RESERVED_3 = 3
Implementations