#[repr(u8)]pub enum Tres {
TRES_0 = 0,
TRES_1 = 1,
}Variants
TRES_0 = 0
Trigger sequences interrupted by a high priority trigger exception will not be automatically resumed or restarted.
TRES_1 = 1
Trigger sequences interrupted by a high priority trigger exception will be automatically resumed or restarted.
Implementations