pub struct TcompFlag(/* private fields */);Implementations
Sourceimpl TcompFlag
impl TcompFlag
Sourcepub const TCOMP_FLAG_0: Self
pub const TCOMP_FLAG_0: Self
No triggers have been completed. Trigger completion interrupts are disabled.
Sourcepub const TCOMP_FLAG_1: Self
pub const TCOMP_FLAG_1: Self
Trigger 0 has been completed and triger 0 has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_2: Self
pub const TCOMP_FLAG_2: Self
Trigger 1 has been completed and triger 1 has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_3: Self
pub const TCOMP_FLAG_3: Self
Associated trigger sequence has completed and has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_4: Self
pub const TCOMP_FLAG_4: Self
Associated trigger sequence has completed and has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_5: Self
pub const TCOMP_FLAG_5: Self
Associated trigger sequence has completed and has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_6: Self
pub const TCOMP_FLAG_6: Self
Associated trigger sequence has completed and has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_7: Self
pub const TCOMP_FLAG_7: Self
Associated trigger sequence has completed and has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_8: Self
pub const TCOMP_FLAG_8: Self
Associated trigger sequence has completed and has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_9: Self
pub const TCOMP_FLAG_9: Self
Associated trigger sequence has completed and has enabled completion interrupts.
Sourcepub const TCOMP_FLAG_65535: Self
pub const TCOMP_FLAG_65535: Self
Every trigger sequence has been completed and every trigger has enabled completion interrupts.